# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from dataclasses import dataclass
import typing_extensions
import urllib3
from urllib3._collections import HTTPHeaderDict

from circle import api_client, exceptions
from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from circle import schemas  # noqa: F401

from circle.model.not_authorized import NotAuthorized
from circle.model.get_business_deposit_address_response import GetBusinessDepositAddressResponse

XRequestIdSchema = schemas.UUIDSchema
SchemaFor200ResponseBodyApplicationJson = GetBusinessDepositAddressResponse
ResponseHeadersFor200 = typing_extensions.TypedDict(
    'ResponseHeadersFor200',
    {
        'X-Request-Id': XRequestIdSchema,
    }
)


@dataclass
class ApiResponseFor200(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: typing.Union[
        SchemaFor200ResponseBodyApplicationJson,
    ]
    headers: ResponseHeadersFor200


_response_for_200 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor200,
    content={
        'application/json': api_client.MediaType(
            schema=SchemaFor200ResponseBodyApplicationJson),
    },
    headers=[
        x_request_id_parameter,
    ]
)
XRequestIdSchema = schemas.UUIDSchema
SchemaFor401ResponseBodyApplicationJson = NotAuthorized
ResponseHeadersFor401 = typing_extensions.TypedDict(
    'ResponseHeadersFor401',
    {
        'X-Request-Id': XRequestIdSchema,
    }
)


@dataclass
class ApiResponseFor401(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: typing.Union[
        SchemaFor401ResponseBodyApplicationJson,
    ]
    headers: ResponseHeadersFor401


_response_for_401 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor401,
    content={
        'application/json': api_client.MediaType(
            schema=SchemaFor401ResponseBodyApplicationJson),
    },
    headers=[
        x_request_id_parameter,
    ]
)
_all_accept_content_types = (
    'application/json',
)


class BaseApi(api_client.Api):
    @typing.overload
    def _get_business_deposit_address_oapg(
        self,
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: typing_extensions.Literal[False] = ...,
    ) -> typing.Union[
        ApiResponseFor200,
    ]: ...

    @typing.overload
    def _get_business_deposit_address_oapg(
        self,
        skip_deserialization: typing_extensions.Literal[True],
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
    ) -> api_client.ApiResponseWithoutDeserialization: ...

    @typing.overload
    def _get_business_deposit_address_oapg(
        self,
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = ...,
    ) -> typing.Union[
        ApiResponseFor200,
        api_client.ApiResponseWithoutDeserialization,
    ]: ...

    def _get_business_deposit_address_oapg(
        self,
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ):
        """
        List all deposit addresses
        :param skip_deserialization: If true then api_response.response will be set but
            api_response.body and api_response.headers will not be deserialized into schema
            class instances
        """
        used_path = path.value

        _headers = HTTPHeaderDict()
        # TODO add cookie handling
        if accept_content_types:
            for accept_content_type in accept_content_types:
                _headers.add('Accept', accept_content_type)

        response = self.api_client.call_api(
            resource_path=used_path,
            method='get'.upper(),
            headers=_headers,
            auth_settings=_auth,
            stream=stream,
            timeout=timeout,
        )

        if skip_deserialization:
            api_response = api_client.ApiResponseWithoutDeserialization(response=response)
        else:
            response_for_status = _status_code_to_response.get(str(response.status))
            if response_for_status:
                api_response = response_for_status.deserialize(response, self.api_client.configuration)
            else:
                api_response = api_client.ApiResponseWithoutDeserialization(response=response)

        if not 200 <= response.status <= 299:
            raise exceptions.ApiException(
                status=response.status,
                reason=response.reason,
                api_response=api_response
            )

        return api_response


class GetBusinessDepositAddress(BaseApi):
    # this class is used by api classes that refer to endpoints with operationId fn names

    @typing.overload
    def get_business_deposit_address(
        self,
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: typing_extensions.Literal[False] = ...,
    ) -> typing.Union[
        ApiResponseFor200,
    ]: ...

    @typing.overload
    def get_business_deposit_address(
        self,
        skip_deserialization: typing_extensions.Literal[True],
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
    ) -> api_client.ApiResponseWithoutDeserialization: ...

    @typing.overload
    def get_business_deposit_address(
        self,
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = ...,
    ) -> typing.Union[
        ApiResponseFor200,
        api_client.ApiResponseWithoutDeserialization,
    ]: ...

    def get_business_deposit_address(
        self,
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ):
        return self._get_business_deposit_address_oapg(
            accept_content_types=accept_content_types,
            stream=stream,
            timeout=timeout,
            skip_deserialization=skip_deserialization
        )


class ApiForget(BaseApi):
    # this class is used by api classes that refer to endpoints by path and http method names

    @typing.overload
    def get(
        self,
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: typing_extensions.Literal[False] = ...,
    ) -> typing.Union[
        ApiResponseFor200,
    ]: ...

    @typing.overload
    def get(
        self,
        skip_deserialization: typing_extensions.Literal[True],
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
    ) -> api_client.ApiResponseWithoutDeserialization: ...

    @typing.overload
    def get(
        self,
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = ...,
    ) -> typing.Union[
        ApiResponseFor200,
        api_client.ApiResponseWithoutDeserialization,
    ]: ...

    def get(
        self,
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ):
        return self._get_business_deposit_address_oapg(
            accept_content_types=accept_content_types,
            stream=stream,
            timeout=timeout,
            skip_deserialization=skip_deserialization
        )





# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from circle import schemas  # noqa: F401


class PaymentCreationRequest(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "amount",
            "metadata",
            "idempotencyKey",
            "source",
            "verification",
        }
        
        class properties:
            idempotencyKey = schemas.UUIDSchema
        
            @staticmethod
            def metadata() -> typing.Type['MetadataPayment']:
                return MetadataPayment
        
            @staticmethod
            def amount() -> typing.Type['FiatMoneyUsd']:
                return FiatMoneyUsd
            
            
            class verification(
                schemas.EnumBase,
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    enum_value_to_name = {
                        "none": "NONE",
                        "cvv": "CVV",
                        "three_d_secure": "THREE_D_SECURE",
                    }
                
                @schemas.classproperty
                def NONE(cls):
                    return cls("none")
                
                @schemas.classproperty
                def CVV(cls):
                    return cls("cvv")
                
                @schemas.classproperty
                def THREE_D_SECURE(cls):
                    return cls("three_d_secure")
        
            @staticmethod
            def source() -> typing.Type['Source']:
                return Source
            keyId = schemas.UUIDSchema
            autoCapture = schemas.BoolSchema
            verificationSuccessUrl = schemas.StrSchema
            verificationFailureUrl = schemas.StrSchema
            description = schemas.StrSchema
            encryptedData = schemas.StrSchema
            channel = schemas.UUIDSchema
            __annotations__ = {
                "idempotencyKey": idempotencyKey,
                "metadata": metadata,
                "amount": amount,
                "verification": verification,
                "source": source,
                "keyId": keyId,
                "autoCapture": autoCapture,
                "verificationSuccessUrl": verificationSuccessUrl,
                "verificationFailureUrl": verificationFailureUrl,
                "description": description,
                "encryptedData": encryptedData,
                "channel": channel,
            }
    
    amount: 'FiatMoneyUsd'
    metadata: 'MetadataPayment'
    idempotencyKey: MetaOapg.properties.idempotencyKey
    source: 'Source'
    verification: MetaOapg.properties.verification
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["idempotencyKey"]) -> MetaOapg.properties.idempotencyKey: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["metadata"]) -> 'MetadataPayment': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["amount"]) -> 'FiatMoneyUsd': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["verification"]) -> MetaOapg.properties.verification: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["source"]) -> 'Source': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["keyId"]) -> MetaOapg.properties.keyId: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["autoCapture"]) -> MetaOapg.properties.autoCapture: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["verificationSuccessUrl"]) -> MetaOapg.properties.verificationSuccessUrl: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["verificationFailureUrl"]) -> MetaOapg.properties.verificationFailureUrl: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["description"]) -> MetaOapg.properties.description: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["encryptedData"]) -> MetaOapg.properties.encryptedData: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["channel"]) -> MetaOapg.properties.channel: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["idempotencyKey", "metadata", "amount", "verification", "source", "keyId", "autoCapture", "verificationSuccessUrl", "verificationFailureUrl", "description", "encryptedData", "channel", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["idempotencyKey"]) -> MetaOapg.properties.idempotencyKey: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["metadata"]) -> 'MetadataPayment': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["amount"]) -> 'FiatMoneyUsd': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["verification"]) -> MetaOapg.properties.verification: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["source"]) -> 'Source': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["keyId"]) -> typing.Union[MetaOapg.properties.keyId, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["autoCapture"]) -> typing.Union[MetaOapg.properties.autoCapture, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["verificationSuccessUrl"]) -> typing.Union[MetaOapg.properties.verificationSuccessUrl, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["verificationFailureUrl"]) -> typing.Union[MetaOapg.properties.verificationFailureUrl, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["description"]) -> typing.Union[MetaOapg.properties.description, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["encryptedData"]) -> typing.Union[MetaOapg.properties.encryptedData, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["channel"]) -> typing.Union[MetaOapg.properties.channel, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["idempotencyKey", "metadata", "amount", "verification", "source", "keyId", "autoCapture", "verificationSuccessUrl", "verificationFailureUrl", "description", "encryptedData", "channel", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        amount: 'FiatMoneyUsd',
        metadata: 'MetadataPayment',
        idempotencyKey: typing.Union[MetaOapg.properties.idempotencyKey, str, uuid.UUID, ],
        source: 'Source',
        verification: typing.Union[MetaOapg.properties.verification, str, ],
        keyId: typing.Union[MetaOapg.properties.keyId, str, uuid.UUID, schemas.Unset] = schemas.unset,
        autoCapture: typing.Union[MetaOapg.properties.autoCapture, bool, schemas.Unset] = schemas.unset,
        verificationSuccessUrl: typing.Union[MetaOapg.properties.verificationSuccessUrl, str, schemas.Unset] = schemas.unset,
        verificationFailureUrl: typing.Union[MetaOapg.properties.verificationFailureUrl, str, schemas.Unset] = schemas.unset,
        description: typing.Union[MetaOapg.properties.description, str, schemas.Unset] = schemas.unset,
        encryptedData: typing.Union[MetaOapg.properties.encryptedData, str, schemas.Unset] = schemas.unset,
        channel: typing.Union[MetaOapg.properties.channel, str, uuid.UUID, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'PaymentCreationRequest':
        return super().__new__(
            cls,
            *_args,
            amount=amount,
            metadata=metadata,
            idempotencyKey=idempotencyKey,
            source=source,
            verification=verification,
            keyId=keyId,
            autoCapture=autoCapture,
            verificationSuccessUrl=verificationSuccessUrl,
            verificationFailureUrl=verificationFailureUrl,
            description=description,
            encryptedData=encryptedData,
            channel=channel,
            _configuration=_configuration,
            **kwargs,
        )

from circle.model.fiat_money_usd import FiatMoneyUsd
from circle.model.metadata_payment import MetadataPayment
from circle.model.source import Source



from circle.paths.v1_address_book_recipients_id.get import ApiForget
from circle.paths.v1_address_book_recipients_id.delete import ApiFordelete
from circle.paths.v1_address_book_recipients_id.patch import ApiForpatch


class V1AddressBookRecipientsId(
    ApiForget,
    ApiFordelete,
    ApiForpatch,
):
    pass



# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from circle.paths.v1_balances.get import ListBalances
from circle.paths.v1_business_account_balances.get import ListBusinessBalances


class BalancesApi(
    ListBalances,
    ListBusinessBalances,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from circle import schemas  # noqa: F401


class WireCreationRequestUs(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Relevant fields for U.S. bank accounts.
    """


    class MetaOapg:
        required = {
            "routingNumber",
            "billingDetails",
            "idempotencyKey",
            "accountNumber",
            "bankAddress",
        }
        
        class properties:
            idempotencyKey = schemas.UUIDSchema
            
            
            class accountNumber(
                schemas.StrSchema
            ):
                pass
            routingNumber = schemas.StrSchema
        
            @staticmethod
            def billingDetails() -> typing.Type['BillingDetails']:
                return BillingDetails
        
            @staticmethod
            def bankAddress() -> typing.Type['BankAddress']:
                return BankAddress
            __annotations__ = {
                "idempotencyKey": idempotencyKey,
                "accountNumber": accountNumber,
                "routingNumber": routingNumber,
                "billingDetails": billingDetails,
                "bankAddress": bankAddress,
            }
    
    routingNumber: MetaOapg.properties.routingNumber
    billingDetails: 'BillingDetails'
    idempotencyKey: MetaOapg.properties.idempotencyKey
    accountNumber: MetaOapg.properties.accountNumber
    bankAddress: 'BankAddress'
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["idempotencyKey"]) -> MetaOapg.properties.idempotencyKey: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["accountNumber"]) -> MetaOapg.properties.accountNumber: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["routingNumber"]) -> MetaOapg.properties.routingNumber: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["billingDetails"]) -> 'BillingDetails': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["bankAddress"]) -> 'BankAddress': ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["idempotencyKey", "accountNumber", "routingNumber", "billingDetails", "bankAddress", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["idempotencyKey"]) -> MetaOapg.properties.idempotencyKey: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["accountNumber"]) -> MetaOapg.properties.accountNumber: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["routingNumber"]) -> MetaOapg.properties.routingNumber: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["billingDetails"]) -> 'BillingDetails': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["bankAddress"]) -> 'BankAddress': ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["idempotencyKey", "accountNumber", "routingNumber", "billingDetails", "bankAddress", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        routingNumber: typing.Union[MetaOapg.properties.routingNumber, str, ],
        billingDetails: 'BillingDetails',
        idempotencyKey: typing.Union[MetaOapg.properties.idempotencyKey, str, uuid.UUID, ],
        accountNumber: typing.Union[MetaOapg.properties.accountNumber, str, ],
        bankAddress: 'BankAddress',
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'WireCreationRequestUs':
        return super().__new__(
            cls,
            *_args,
            routingNumber=routingNumber,
            billingDetails=billingDetails,
            idempotencyKey=idempotencyKey,
            accountNumber=accountNumber,
            bankAddress=bankAddress,
            _configuration=_configuration,
            **kwargs,
        )

from circle.model.bank_address import BankAddress
from circle.model.billing_details import BillingDetails



# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from circle.paths.v1_business_account_wallets_addresses_deposit.post import CreateBusinessDepositAddress
from circle.paths.v1_business_account_wallets_addresses_recipient.post import CreateBusinessRecipientAddress
from circle.paths.v1_business_account_wallets_addresses_deposit.get import GetBusinessDepositAddress
from circle.paths.v1_business_account_wallets_addresses_recipient.get import ListBusinessRecipientAddresses


class AddressesApi(
    CreateBusinessDepositAddress,
    CreateBusinessRecipientAddress,
    GetBusinessDepositAddress,
    ListBusinessRecipientAddresses,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



from circle.paths.v1_business_account_wallets_addresses_deposit.get import ApiForget
from circle.paths.v1_business_account_wallets_addresses_deposit.post import ApiForpost


class V1BusinessAccountWalletsAddressesDeposit(
    ApiForget,
    ApiForpost,
):
    pass



# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from circle.paths.v1_payments_crypto.post import CreateCryptoPayment
from circle.paths.v1_payments_presign.get import Presign


class PullCryptoPaymentsApi(
    CreateCryptoPayment,
    Presign,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from circle import schemas  # noqa: F401


class Stablecoin(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        
        class properties:
            name = schemas.StrSchema
            symbol = schemas.StrSchema
            totalAmount = schemas.StrSchema
            
            
            class chains(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['TokenAmount']:
                        return TokenAmount
            
                def __new__(
                    cls,
                    _arg: typing.Union[typing.Tuple['TokenAmount'], typing.List['TokenAmount']],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'chains':
                    return super().__new__(
                        cls,
                        _arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> 'TokenAmount':
                    return super().__getitem__(i)
            __annotations__ = {
                "name": name,
                "symbol": symbol,
                "totalAmount": totalAmount,
                "chains": chains,
            }
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["symbol"]) -> MetaOapg.properties.symbol: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["totalAmount"]) -> MetaOapg.properties.totalAmount: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["chains"]) -> MetaOapg.properties.chains: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["name", "symbol", "totalAmount", "chains", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["name"]) -> typing.Union[MetaOapg.properties.name, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["symbol"]) -> typing.Union[MetaOapg.properties.symbol, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["totalAmount"]) -> typing.Union[MetaOapg.properties.totalAmount, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["chains"]) -> typing.Union[MetaOapg.properties.chains, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["name", "symbol", "totalAmount", "chains", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        name: typing.Union[MetaOapg.properties.name, str, schemas.Unset] = schemas.unset,
        symbol: typing.Union[MetaOapg.properties.symbol, str, schemas.Unset] = schemas.unset,
        totalAmount: typing.Union[MetaOapg.properties.totalAmount, str, schemas.Unset] = schemas.unset,
        chains: typing.Union[MetaOapg.properties.chains, list, tuple, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'Stablecoin':
        return super().__new__(
            cls,
            *_args,
            name=name,
            symbol=symbol,
            totalAmount=totalAmount,
            chains=chains,
            _configuration=_configuration,
            **kwargs,
        )

from circle.model.token_amount import TokenAmount



import circle
from circle.model.subscription_request import SubscriptionRequest

import unittest


class TestPing(unittest.TestCase):

    def test_create(self):
        model = SubscriptionRequest(
            endpoint='https://example.org/test-create-sub-req'
        )
        self.assertEquals(model['endpoint'], 'https://example.org/test-create-sub-req')

    def test_empty(self):
        with self.assertRaises(TypeError):
            # Shoudl error with TypeError because required constructor params not provided
            SubscriptionRequest()

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from circle import schemas  # noqa: F401


class ChargebackStatus(
    schemas.EnumBase,
    schemas.StrSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Enumerated status of the chargeback. `active` means you’ve received a dispute and you need to submit evidence if you want to defend against it. 'resolved' means the disputed payment had been refunded previously. Your account has not been debited. `pending` means we have acknowledged your evidence and forwarded it to the card issuer. `won` means you have won the dispute and your account has been credited. `lost` means the issuing bank has rejected your evidence and you have lost the dispute. There are no further financial implications. `canceled` means the issuing bank has canceled the dispute and your account has been credited. `closed` means the time to respond to this dispute has run out. No evidence can be submitted at this point.
    """


    class MetaOapg:
        enum_value_to_name = {
            "active": "ACTIVE",
            "resolved": "RESOLVED",
            "pending": "PENDING",
            "won": "WON",
            "lost": "LOST",
            "canceled": "CANCELED",
            "closed": "CLOSED",
        }
    
    @schemas.classproperty
    def ACTIVE(cls):
        return cls("active")
    
    @schemas.classproperty
    def RESOLVED(cls):
        return cls("resolved")
    
    @schemas.classproperty
    def PENDING(cls):
        return cls("pending")
    
    @schemas.classproperty
    def WON(cls):
        return cls("won")
    
    @schemas.classproperty
    def LOST(cls):
        return cls("lost")
    
    @schemas.classproperty
    def CANCELED(cls):
        return cls("canceled")
    
    @schemas.classproperty
    def CLOSED(cls):
        return cls("closed")



# do not import all endpoints into this module because that uses a lot of memory and stack frames
# if you need the ability to import all endpoints from this module, import them with
# from circle.paths.v1_chargebacks import Api

from circle.paths import PathValues

path = PathValues.V1_CHARGEBACKS


# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from setuptools import setup, find_packages  # noqa: H301
import html

NAME = "circle-sdk"
VERSION = "0.1.0-beta.12"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = [
    "certifi >= 14.5.14",
    "frozendict ~= 2.3.4",
    "python-dateutil ~= 2.7.0",
    "setuptools >= 21.0.0",
    "typing_extensions ~= 4.3.0",
    "urllib3 ~= 1.26.7",
]

with open('README.md') as f:
    readme_content = f.read()

setup(
    name=NAME,
    version=VERSION,
    author="Circle SDK Developers",
    author_email="sdk-developers+pypi@circle.com",
    url="",
    keywords=["circle", "circle.com", "usdc", "euroc", "stablecoins"],
    python_requires=">=3.7",
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    description="Python SDK for Circle APIs",
    long_description_content_type="text/markdown",
    long_description=readme_content
)



# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from circle import schemas  # noqa: F401


class CryptoPayment(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Status information of the related payment.
    """


    class MetaOapg:
        required = {
            "amount",
            "merchantId",
            "id",
            "type",
            "status",
        }
        
        class properties:
            id = schemas.UUIDSchema
            
            
            class type(
                schemas.EnumBase,
                schemas.StrSchema
            ):
                
                @schemas.classproperty
                def PAYMENT(cls):
                    return cls("payment")
                
                @schemas.classproperty
                def REFUND(cls):
                    return cls("refund")
            merchantId = schemas.UUIDSchema
        
            @staticmethod
            def amount() -> typing.Type['CryptoPaymentsOptionalAmountMoney']:
                return CryptoPaymentsOptionalAmountMoney
        
            @staticmethod
            def status() -> typing.Type['PaymentStatus']:
                return PaymentStatus
        
            @staticmethod
            def merchantWalletId() -> typing.Type['MerchantWalletId']:
                return MerchantWalletId
        
            @staticmethod
            def fees() -> typing.Type['FiatMoneyUsd']:
                return FiatMoneyUsd
        
            @staticmethod
            def networkFees() -> typing.Type['CryptoPaymentNetworkFee']:
                return CryptoPaymentNetworkFee
            paymentIntentId = schemas.UUIDSchema
        
            @staticmethod
            def settlementAmount() -> typing.Type['FiatMoneyUsd']:
                return FiatMoneyUsd
        
            @staticmethod
            def fromAddresses() -> typing.Type['CryptoPaymentFromAddresses']:
                return CryptoPaymentFromAddresses
        
            @staticmethod
            def depositAddress() -> typing.Type['CryptoPaymentDepositAddress']:
                return CryptoPaymentDepositAddress
            transactionHash = schemas.StrSchema
            createDate = schemas.StrSchema
            updateDate = schemas.StrSchema
        
            @staticmethod
            def riskEvaluation() -> typing.Type['RiskEvaluation']:
                return RiskEvaluation
            __annotations__ = {
                "id": id,
                "type": type,
                "merchantId": merchantId,
                "amount": amount,
                "status": status,
                "merchantWalletId": merchantWalletId,
                "fees": fees,
                "networkFees": networkFees,
                "paymentIntentId": paymentIntentId,
                "settlementAmount": settlementAmount,
                "fromAddresses": fromAddresses,
                "depositAddress": depositAddress,
                "transactionHash": transactionHash,
                "createDate": createDate,
                "updateDate": updateDate,
                "riskEvaluation": riskEvaluation,
            }
    
    amount: 'CryptoPaymentsOptionalAmountMoney'
    merchantId: MetaOapg.properties.merchantId
    id: MetaOapg.properties.id
    type: MetaOapg.properties.type
    status: 'PaymentStatus'
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["type"]) -> MetaOapg.properties.type: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["merchantId"]) -> MetaOapg.properties.merchantId: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["amount"]) -> 'CryptoPaymentsOptionalAmountMoney': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["status"]) -> 'PaymentStatus': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["merchantWalletId"]) -> 'MerchantWalletId': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["fees"]) -> 'FiatMoneyUsd': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["networkFees"]) -> 'CryptoPaymentNetworkFee': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["paymentIntentId"]) -> MetaOapg.properties.paymentIntentId: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["settlementAmount"]) -> 'FiatMoneyUsd': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["fromAddresses"]) -> 'CryptoPaymentFromAddresses': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["depositAddress"]) -> 'CryptoPaymentDepositAddress': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["transactionHash"]) -> MetaOapg.properties.transactionHash: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["createDate"]) -> MetaOapg.properties.createDate: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["updateDate"]) -> MetaOapg.properties.updateDate: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["riskEvaluation"]) -> 'RiskEvaluation': ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["id", "type", "merchantId", "amount", "status", "merchantWalletId", "fees", "networkFees", "paymentIntentId", "settlementAmount", "fromAddresses", "depositAddress", "transactionHash", "createDate", "updateDate", "riskEvaluation", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["type"]) -> MetaOapg.properties.type: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["merchantId"]) -> MetaOapg.properties.merchantId: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["amount"]) -> 'CryptoPaymentsOptionalAmountMoney': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["status"]) -> 'PaymentStatus': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["merchantWalletId"]) -> typing.Union['MerchantWalletId', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["fees"]) -> typing.Union['FiatMoneyUsd', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["networkFees"]) -> typing.Union['CryptoPaymentNetworkFee', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["paymentIntentId"]) -> typing.Union[MetaOapg.properties.paymentIntentId, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["settlementAmount"]) -> typing.Union['FiatMoneyUsd', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["fromAddresses"]) -> typing.Union['CryptoPaymentFromAddresses', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["depositAddress"]) -> typing.Union['CryptoPaymentDepositAddress', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["transactionHash"]) -> typing.Union[MetaOapg.properties.transactionHash, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["createDate"]) -> typing.Union[MetaOapg.properties.createDate, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["updateDate"]) -> typing.Union[MetaOapg.properties.updateDate, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["riskEvaluation"]) -> typing.Union['RiskEvaluation', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["id", "type", "merchantId", "amount", "status", "merchantWalletId", "fees", "networkFees", "paymentIntentId", "settlementAmount", "fromAddresses", "depositAddress", "transactionHash", "createDate", "updateDate", "riskEvaluation", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        amount: 'CryptoPaymentsOptionalAmountMoney',
        merchantId: typing.Union[MetaOapg.properties.merchantId, str, uuid.UUID, ],
        id: typing.Union[MetaOapg.properties.id, str, uuid.UUID, ],
        type: typing.Union[MetaOapg.properties.type, str, ],
        status: 'PaymentStatus',
        merchantWalletId: typing.Union['MerchantWalletId', schemas.Unset] = schemas.unset,
        fees: typing.Union['FiatMoneyUsd', schemas.Unset] = schemas.unset,
        networkFees: typing.Union['CryptoPaymentNetworkFee', schemas.Unset] = schemas.unset,
        paymentIntentId: typing.Union[MetaOapg.properties.paymentIntentId, str, uuid.UUID, schemas.Unset] = schemas.unset,
        settlementAmount: typing.Union['FiatMoneyUsd', schemas.Unset] = schemas.unset,
        fromAddresses: typing.Union['CryptoPaymentFromAddresses', schemas.Unset] = schemas.unset,
        depositAddress: typing.Union['CryptoPaymentDepositAddress', schemas.Unset] = schemas.unset,
        transactionHash: typing.Union[MetaOapg.properties.transactionHash, str, schemas.Unset] = schemas.unset,
        createDate: typing.Union[MetaOapg.properties.createDate, str, schemas.Unset] = schemas.unset,
        updateDate: typing.Union[MetaOapg.properties.updateDate, str, schemas.Unset] = schemas.unset,
        riskEvaluation: typing.Union['RiskEvaluation', schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'CryptoPayment':
        return super().__new__(
            cls,
            *_args,
            amount=amount,
            merchantId=merchantId,
            id=id,
            type=type,
            status=status,
            merchantWalletId=merchantWalletId,
            fees=fees,
            networkFees=networkFees,
            paymentIntentId=paymentIntentId,
            settlementAmount=settlementAmount,
            fromAddresses=fromAddresses,
            depositAddress=depositAddress,
            transactionHash=transactionHash,
            createDate=createDate,
            updateDate=updateDate,
            riskEvaluation=riskEvaluation,
            _configuration=_configuration,
            **kwargs,
        )

from circle.model.crypto_payment_deposit_address import CryptoPaymentDepositAddress
from circle.model.crypto_payment_from_addresses import CryptoPaymentFromAddresses
from circle.model.crypto_payment_network_fee import CryptoPaymentNetworkFee
from circle.model.crypto_payments_optional_amount_money import CryptoPaymentsOptionalAmountMoney
from circle.model.fiat_money_usd import FiatMoneyUsd
from circle.model.merchant_wallet_id import MerchantWalletId
from circle.model.payment_status import PaymentStatus
from circle.model.risk_evaluation import RiskEvaluation



# coding: utf-8

# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from circle.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from circle.model.account_configuration import AccountConfiguration
from circle.model.address import Address
from circle.model.address_book_recipient import AddressBookRecipient
from circle.model.address_book_recipient_metadata import AddressBookRecipientMetadata
from circle.model.address_book_recipient_modify_request import AddressBookRecipientModifyRequest
from circle.model.address_book_recipient_request import AddressBookRecipientRequest
from circle.model.address_description import AddressDescription
from circle.model.address_object import AddressObject
from circle.model.address_tag import AddressTag
from circle.model.apple_pay_token import ApplePayToken
from circle.model.apple_pay_token_ec_header import ApplePayTokenEcHeader
from circle.model.apple_pay_token_header import ApplePayTokenHeader
from circle.model.apple_pay_token_rsa_header import ApplePayTokenRsaHeader
from circle.model.avs_results import AvsResults
from circle.model.bad_request import BadRequest
from circle.model.balances import Balances
from circle.model.bank_address import BankAddress
from circle.model.bank_address_iban_supported import BankAddressIbanSupported
from circle.model.bank_address_non_iban import BankAddressNonIban
from circle.model.bank_destination import BankDestination
from circle.model.basic_chargeback import BasicChargeback
from circle.model.basic_chargeback_history import BasicChargebackHistory
from circle.model.billing_details import BillingDetails
from circle.model.business_account_payout_destination_type import BusinessAccountPayoutDestinationType
from circle.model.business_deposit import BusinessDeposit
from circle.model.business_destination_request import BusinessDestinationRequest
from circle.model.business_generate_address_request import BusinessGenerateAddressRequest
from circle.model.business_payout import BusinessPayout
from circle.model.business_payout_creation_request import BusinessPayoutCreationRequest
from circle.model.business_recipient_address_creation_request import BusinessRecipientAddressCreationRequest
from circle.model.business_recipient_address_object import BusinessRecipientAddressObject
from circle.model.business_transfer_creation_request import BusinessTransferCreationRequest
from circle.model.cancel_creation_request import CancelCreationRequest
from circle.model.cancel_payment_response import CancelPaymentResponse
from circle.model.cancel_refund_reversal_status import CancelRefundReversalStatus
from circle.model.capture_creation_request import CaptureCreationRequest
from circle.model.card import Card
from circle.model.card_creation_request import CardCreationRequest
from circle.model.card_exp_month import CardExpMonth
from circle.model.card_exp_year import CardExpYear
from circle.model.card_update import CardUpdate
from circle.model.card_verification_response import CardVerificationResponse
from circle.model.cbit_fiat_account_creation_request import CbitFiatAccountCreationRequest
from circle.model.cbit_fiat_account_response import CbitFiatAccountResponse
from circle.model.cbit_instruction import CbitInstruction
from circle.model.chain import Chain
from circle.model.channel import Channel
from circle.model.channel_response import ChannelResponse
from circle.model.chargeback_categories import ChargebackCategories
from circle.model.chargeback_status import ChargebackStatus
from circle.model.checkout_session import CheckoutSession
from circle.model.checkout_session_creation_request import CheckoutSessionCreationRequest
from circle.model.checkout_session_money import CheckoutSessionMoney
from circle.model.checkout_session_status import CheckoutSessionStatus
from circle.model.conflict import Conflict
from circle.model.continuous_payment_intent import ContinuousPaymentIntent
from circle.model.continuous_payment_intent_creation_request import ContinuousPaymentIntentCreationRequest
from circle.model.create_address_book_recipient_response import CreateAddressBookRecipientResponse
from circle.model.create_business_cbit_account_response import CreateBusinessCbitAccountResponse
from circle.model.create_business_deposit_address_response import CreateBusinessDepositAddressResponse
from circle.model.create_business_payout_response import CreateBusinessPayoutResponse
from circle.model.create_business_recipient_address_response import CreateBusinessRecipientAddressResponse
from circle.model.create_business_transfer_response import CreateBusinessTransferResponse
from circle.model.create_business_wire_account_response import CreateBusinessWireAccountResponse
from circle.model.create_card_response import CreateCardResponse
from circle.model.create_checkout_session_response import CreateCheckoutSessionResponse
from circle.model.create_crypto_payment_response import CreateCryptoPaymentResponse
from circle.model.create_crypto_payment_response1 import CreateCryptoPaymentResponse1
from circle.model.create_crypto_refund_response import CreateCryptoRefundResponse
from circle.model.create_mock_chargeback_response import CreateMockChargebackResponse
from circle.model.create_payment_intent_request import CreatePaymentIntentRequest
from circle.model.create_payment_intent_response import CreatePaymentIntentResponse
from circle.model.create_payment_intent_response_data import CreatePaymentIntentResponseData
from circle.model.create_payment_response import CreatePaymentResponse
from circle.model.create_payment_token_response import CreatePaymentTokenResponse
from circle.model.create_payout_response import CreatePayoutResponse
from circle.model.create_subscription_response import CreateSubscriptionResponse
from circle.model.create_transfer_response import CreateTransferResponse
from circle.model.create_wallet_response import CreateWalletResponse
from circle.model.create_wire_payment_response import CreateWirePaymentResponse
from circle.model.crypto_payment import CryptoPayment
from circle.model.crypto_payment_creation_request import CryptoPaymentCreationRequest
from circle.model.crypto_payment_deposit_address import CryptoPaymentDepositAddress
from circle.model.crypto_payment_destination import CryptoPaymentDestination
from circle.model.crypto_payment_from_addresses import CryptoPaymentFromAddresses
from circle.model.crypto_payment_network_fee import CryptoPaymentNetworkFee
from circle.model.crypto_payment_source import CryptoPaymentSource
from circle.model.crypto_payments_money import CryptoPaymentsMoney
from circle.model.crypto_payments_optional_amount_money import CryptoPaymentsOptionalAmountMoney
from circle.model.crypto_payout import CryptoPayout
from circle.model.crypto_payout_creation_request import CryptoPayoutCreationRequest
from circle.model.crypto_payout_destination import CryptoPayoutDestination
from circle.model.crypto_payout_destination_type import CryptoPayoutDestinationType
from circle.model.crypto_refund_creation_request import CryptoRefundCreationRequest
from circle.model.crypto_refund_creation_request_amount import CryptoRefundCreationRequestAmount
from circle.model.crypto_refund_creation_request_to_amount import CryptoRefundCreationRequestToAmount
from circle.model.crypto_refund_destination import CryptoRefundDestination
from circle.model.currency import Currency
from circle.model.cvv_results import CvvResults
from circle.model.delete_subscription_response import DeleteSubscriptionResponse
from circle.model.detailed_cancel import DetailedCancel
from circle.model.detailed_payment import DetailedPayment
from circle.model.detailed_refund import DetailedRefund
from circle.model.eci import Eci
from circle.model.email import Email
from circle.model.expire_payment_intent_response import ExpirePaymentIntentResponse
from circle.model.extend_checkout_session_request import ExtendCheckoutSessionRequest
from circle.model.extend_checkout_session_response import ExtendCheckoutSessionResponse
from circle.model.external_fiat_account_status import ExternalFiatAccountStatus
from circle.model.external_ref import ExternalRef
from circle.model.fee import Fee
from circle.model.fiat_cancel import FiatCancel
from circle.model.fiat_money import FiatMoney
from circle.model.fiat_money_usd import FiatMoneyUsd
from circle.model.fiat_payment import FiatPayment
from circle.model.fiat_payment_polymorphic import FiatPaymentPolymorphic
from circle.model.fiat_refund import FiatRefund
from circle.model.final_adjustments import FinalAdjustments
from circle.model.fingerprint import Fingerprint
from circle.model.forbidden import Forbidden
from circle.model.generate_address_request import GenerateAddressRequest
from circle.model.generate_address_response import GenerateAddressResponse
from circle.model.get_address_book_recipient_response import GetAddressBookRecipientResponse
from circle.model.get_business_cbit_account_response import GetBusinessCbitAccountResponse
from circle.model.get_business_deposit_address_response import GetBusinessDepositAddressResponse
from circle.model.get_business_payout_response import GetBusinessPayoutResponse
from circle.model.get_business_transfer_response import GetBusinessTransferResponse
from circle.model.get_business_wire_account_instructions_response import GetBusinessWireAccountInstructionsResponse
from circle.model.get_business_wire_account_response import GetBusinessWireAccountResponse
from circle.model.get_card_response import GetCardResponse
from circle.model.get_chargeback_response import GetChargebackResponse
from circle.model.get_checkout_session_response import GetCheckoutSessionResponse
from circle.model.get_config_response import GetConfigResponse
from circle.model.get_exchange_rates_response import GetExchangeRatesResponse
from circle.model.get_payment_intent_response import GetPaymentIntentResponse
from circle.model.get_payment_response import GetPaymentResponse
from circle.model.get_payment_response_data import GetPaymentResponseData
from circle.model.get_payout_response import GetPayoutResponse
from circle.model.get_public_key_response import GetPublicKeyResponse
from circle.model.get_settlement_response import GetSettlementResponse
from circle.model.get_settlements_response import GetSettlementsResponse
from circle.model.get_transfer_response import GetTransferResponse
from circle.model.get_wallet_response import GetWalletResponse
from circle.model.google_pay_token import GooglePayToken
from circle.model.id import Id
from circle.model.id_key import IdKey
from circle.model.id_merchant import IdMerchant
from circle.model.id_payment import IdPayment
from circle.model.id_payout import IdPayout
from circle.model.id_settlement import IdSettlement
from circle.model.idempotency_key import IdempotencyKey
from circle.model.identity import Identity
from circle.model.identity_address import IdentityAddress
from circle.model.ip_address import IpAddress
from circle.model.limit_exceeded import LimitExceeded
from circle.model.list_address_book_recipients_response import ListAddressBookRecipientsResponse
from circle.model.list_addresses_response import ListAddressesResponse
from circle.model.list_balances_response import ListBalancesResponse
from circle.model.list_business_balances_response import ListBusinessBalancesResponse
from circle.model.list_business_cbit_account_instructions_response import ListBusinessCbitAccountInstructionsResponse
from circle.model.list_business_cbit_accounts_response import ListBusinessCbitAccountsResponse
from circle.model.list_business_deposits_response import ListBusinessDepositsResponse
from circle.model.list_business_payouts_response import ListBusinessPayoutsResponse
from circle.model.list_business_recipient_addresses_response import ListBusinessRecipientAddressesResponse
from circle.model.list_business_transfers_response import ListBusinessTransfersResponse
from circle.model.list_business_wire_accounts_response import ListBusinessWireAccountsResponse
from circle.model.list_cards_response import ListCardsResponse
from circle.model.list_channels_response import ListChannelsResponse
from circle.model.list_chargebacks_response import ListChargebacksResponse
from circle.model.list_checkout_sessions_response import ListCheckoutSessionsResponse
from circle.model.list_payment_intents_response import ListPaymentIntentsResponse
from circle.model.list_payment_intents_response_data_inner import ListPaymentIntentsResponseDataInner
from circle.model.list_payments_response import ListPaymentsResponse
from circle.model.list_payments_response_data_inner import ListPaymentsResponseDataInner
from circle.model.list_payouts_response import ListPayoutsResponse
from circle.model.list_stablecoins_response import ListStablecoinsResponse
from circle.model.list_subscriptions_response import ListSubscriptionsResponse
from circle.model.list_transfers_response import ListTransfersResponse
from circle.model.list_wallets_response import ListWalletsResponse
from circle.model.merchant_wallet_id import MerchantWalletId
from circle.model.metadata_card_and_ach import MetadataCardAndAch
from circle.model.metadata_crypto_payment import MetadataCryptoPayment
from circle.model.metadata_payment import MetadataPayment
from circle.model.metadata_phone_email import MetadataPhoneEmail
from circle.model.mock_chargeback_creation_request import MockChargebackCreationRequest
from circle.model.mock_wire_payment_beneficiary_bank_instruction import MockWirePaymentBeneficiaryBankInstruction
from circle.model.mock_wire_payment_request import MockWirePaymentRequest
from circle.model.mock_wire_payment_response import MockWirePaymentResponse
from circle.model.modify_address_book_recipient_response import ModifyAddressBookRecipientResponse
from circle.model.money import Money
from circle.model.network_fee_quote import NetworkFeeQuote
from circle.model.not_authorized import NotAuthorized
from circle.model.not_found import NotFound
from circle.model.payment_creation_request import PaymentCreationRequest
from circle.model.payment_error_code import PaymentErrorCode
from circle.model.payment_info_cancel import PaymentInfoCancel
from circle.model.payment_info_payment_and_refund import PaymentInfoPaymentAndRefund
from circle.model.payment_intent import PaymentIntent
from circle.model.payment_intent_creation_request import PaymentIntentCreationRequest
from circle.model.payment_intent_fees import PaymentIntentFees
from circle.model.payment_method_blockchain import PaymentMethodBlockchain
from circle.model.payment_status import PaymentStatus
from circle.model.payment_token import PaymentToken
from circle.model.payment_token_request import PaymentTokenRequest
from circle.model.payment_token_request_token_data import PaymentTokenRequestTokenData
from circle.model.payment_verification_response import PaymentVerificationResponse
from circle.model.payout_destination_type import PayoutDestinationType
from circle.model.payout_error_code import PayoutErrorCode
from circle.model.payout_money import PayoutMoney
from circle.model.payout_status import PayoutStatus
from circle.model.phone_number import PhoneNumber
from circle.model.ping import Ping
from circle.model.presign_domain import PresignDomain
from circle.model.presign_message import PresignMessage
from circle.model.presign_message_types import PresignMessageTypes
from circle.model.presign_message_types_items import PresignMessageTypesItems
from circle.model.presign_response import PresignResponse
from circle.model.presign_response_typed_data import PresignResponseTypedData
from circle.model.public_key import PublicKey
from circle.model.rate import Rate
from circle.model.refund_creation_request import RefundCreationRequest
from circle.model.refund_payment_response import RefundPaymentResponse
from circle.model.required_action import RequiredAction
from circle.model.reversal_reason import ReversalReason
from circle.model.risk_evaluation import RiskEvaluation
from circle.model.session_id import SessionId
from circle.model.settlement import Settlement
from circle.model.simple_billing_details import SimpleBillingDetails
from circle.model.simple_card import SimpleCard
from circle.model.source import Source
from circle.model.source_response import SourceResponse
from circle.model.stablecoin import Stablecoin
from circle.model.stablecoins import Stablecoins
from circle.model.subscription_detail import SubscriptionDetail
from circle.model.subscription_request import SubscriptionRequest
from circle.model.subscription_response import SubscriptionResponse
from circle.model.success_url import SuccessUrl
from circle.model.three_ds_result import ThreeDsResult
from circle.model.timeline import Timeline
from circle.model.to_amount import ToAmount
from circle.model.token_amount import TokenAmount
from circle.model.tokenized_card_details import TokenizedCardDetails
from circle.model.transfer import Transfer
from circle.model.transfer_creation_request import TransferCreationRequest
from circle.model.transfer_creation_request_destination import TransferCreationRequestDestination
from circle.model.transfer_destination_blockchain_location import TransferDestinationBlockchainLocation
from circle.model.transfer_destination_location import TransferDestinationLocation
from circle.model.transfer_destination_wallet_location import TransferDestinationWalletLocation
from circle.model.transfer_detailed_transfer import TransferDetailedTransfer
from circle.model.transfer_error_code import TransferErrorCode
from circle.model.transfer_request_blockchain_location import TransferRequestBlockchainLocation
from circle.model.transfer_request_source_wallet_location import TransferRequestSourceWalletLocation
from circle.model.transfer_request_verified_blockchain_location import TransferRequestVerifiedBlockchainLocation
from circle.model.transfer_source_blockchain_location import TransferSourceBlockchainLocation
from circle.model.transfer_source_location import TransferSourceLocation
from circle.model.transfer_source_wallet_location import TransferSourceWalletLocation
from circle.model.unwithdrawal_object import UnwithdrawalObject
from circle.model.update_billing_details import UpdateBillingDetails
from circle.model.update_card_response import UpdateCardResponse
from circle.model.utc_timestamp import UtcTimestamp
from circle.model.verification_error_code import VerificationErrorCode
from circle.model.wallet import Wallet
from circle.model.wallet_config import WalletConfig
from circle.model.wallet_creation_request import WalletCreationRequest
from circle.model.wallet_location import WalletLocation
from circle.model.wire import Wire
from circle.model.wire_creation_request import WireCreationRequest
from circle.model.wire_creation_request_account_number import WireCreationRequestAccountNumber
from circle.model.wire_creation_request_iban import WireCreationRequestIban
from circle.model.wire_creation_request_us import WireCreationRequestUs
from circle.model.wire_instruction import WireInstruction
from circle.model.wire_instruction_beneficiary import WireInstructionBeneficiary
from circle.model.wire_instruction_beneficiary_bank import WireInstructionBeneficiaryBank



# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from circle import schemas  # noqa: F401


class Settlement(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        
        class properties:
            id = schemas.UUIDSchema
        
            @staticmethod
            def merchantWalletId() -> typing.Type['MerchantWalletId']:
                return MerchantWalletId
            walletId = schemas.StrSchema
        
            @staticmethod
            def totalDebits() -> typing.Type['FiatMoneyUsd']:
                return FiatMoneyUsd
        
            @staticmethod
            def totalCredits() -> typing.Type['FiatMoneyUsd']:
                return FiatMoneyUsd
        
            @staticmethod
            def paymentFees() -> typing.Type['FiatMoneyUsd']:
                return FiatMoneyUsd
        
            @staticmethod
            def chargebackFees() -> typing.Type['FiatMoneyUsd']:
                return FiatMoneyUsd
            createDate = schemas.StrSchema
            updateDate = schemas.StrSchema
            __annotations__ = {
                "id": id,
                "merchantWalletId": merchantWalletId,
                "walletId": walletId,
                "totalDebits": totalDebits,
                "totalCredits": totalCredits,
                "paymentFees": paymentFees,
                "chargebackFees": chargebackFees,
                "createDate": createDate,
                "updateDate": updateDate,
            }
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["merchantWalletId"]) -> 'MerchantWalletId': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["walletId"]) -> MetaOapg.properties.walletId: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["totalDebits"]) -> 'FiatMoneyUsd': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["totalCredits"]) -> 'FiatMoneyUsd': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["paymentFees"]) -> 'FiatMoneyUsd': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["chargebackFees"]) -> 'FiatMoneyUsd': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["createDate"]) -> MetaOapg.properties.createDate: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["updateDate"]) -> MetaOapg.properties.updateDate: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["id", "merchantWalletId", "walletId", "totalDebits", "totalCredits", "paymentFees", "chargebackFees", "createDate", "updateDate", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["id"]) -> typing.Union[MetaOapg.properties.id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["merchantWalletId"]) -> typing.Union['MerchantWalletId', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["walletId"]) -> typing.Union[MetaOapg.properties.walletId, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["totalDebits"]) -> typing.Union['FiatMoneyUsd', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["totalCredits"]) -> typing.Union['FiatMoneyUsd', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["paymentFees"]) -> typing.Union['FiatMoneyUsd', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["chargebackFees"]) -> typing.Union['FiatMoneyUsd', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["createDate"]) -> typing.Union[MetaOapg.properties.createDate, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["updateDate"]) -> typing.Union[MetaOapg.properties.updateDate, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["id", "merchantWalletId", "walletId", "totalDebits", "totalCredits", "paymentFees", "chargebackFees", "createDate", "updateDate", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        id: typing.Union[MetaOapg.properties.id, str, uuid.UUID, schemas.Unset] = schemas.unset,
        merchantWalletId: typing.Union['MerchantWalletId', schemas.Unset] = schemas.unset,
        walletId: typing.Union[MetaOapg.properties.walletId, str, schemas.Unset] = schemas.unset,
        totalDebits: typing.Union['FiatMoneyUsd', schemas.Unset] = schemas.unset,
        totalCredits: typing.Union['FiatMoneyUsd', schemas.Unset] = schemas.unset,
        paymentFees: typing.Union['FiatMoneyUsd', schemas.Unset] = schemas.unset,
        chargebackFees: typing.Union['FiatMoneyUsd', schemas.Unset] = schemas.unset,
        createDate: typing.Union[MetaOapg.properties.createDate, str, schemas.Unset] = schemas.unset,
        updateDate: typing.Union[MetaOapg.properties.updateDate, str, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'Settlement':
        return super().__new__(
            cls,
            *_args,
            id=id,
            merchantWalletId=merchantWalletId,
            walletId=walletId,
            totalDebits=totalDebits,
            totalCredits=totalCredits,
            paymentFees=paymentFees,
            chargebackFees=chargebackFees,
            createDate=createDate,
            updateDate=updateDate,
            _configuration=_configuration,
            **kwargs,
        )

from circle.model.fiat_money_usd import FiatMoneyUsd
from circle.model.merchant_wallet_id import MerchantWalletId



# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from circle import schemas  # noqa: F401


class MockWirePaymentRequest(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "beneficiaryBank",
            "trackingRef",
            "amount",
        }
        
        class properties:
            trackingRef = schemas.StrSchema
        
            @staticmethod
            def amount() -> typing.Type['FiatMoneyUsd']:
                return FiatMoneyUsd
        
            @staticmethod
            def beneficiaryBank() -> typing.Type['MockWirePaymentBeneficiaryBankInstruction']:
                return MockWirePaymentBeneficiaryBankInstruction
            __annotations__ = {
                "trackingRef": trackingRef,
                "amount": amount,
                "beneficiaryBank": beneficiaryBank,
            }
    
    beneficiaryBank: 'MockWirePaymentBeneficiaryBankInstruction'
    trackingRef: MetaOapg.properties.trackingRef
    amount: 'FiatMoneyUsd'
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["trackingRef"]) -> MetaOapg.properties.trackingRef: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["amount"]) -> 'FiatMoneyUsd': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["beneficiaryBank"]) -> 'MockWirePaymentBeneficiaryBankInstruction': ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["trackingRef", "amount", "beneficiaryBank", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["trackingRef"]) -> MetaOapg.properties.trackingRef: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["amount"]) -> 'FiatMoneyUsd': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["beneficiaryBank"]) -> 'MockWirePaymentBeneficiaryBankInstruction': ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["trackingRef", "amount", "beneficiaryBank", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        beneficiaryBank: 'MockWirePaymentBeneficiaryBankInstruction',
        trackingRef: typing.Union[MetaOapg.properties.trackingRef, str, ],
        amount: 'FiatMoneyUsd',
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'MockWirePaymentRequest':
        return super().__new__(
            cls,
            *_args,
            beneficiaryBank=beneficiaryBank,
            trackingRef=trackingRef,
            amount=amount,
            _configuration=_configuration,
            **kwargs,
        )

from circle.model.fiat_money_usd import FiatMoneyUsd
from circle.model.mock_wire_payment_beneficiary_bank_instruction import MockWirePaymentBeneficiaryBankInstruction



# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from circle import schemas  # noqa: F401


class ApplePayToken(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "data",
            "signature",
            "header",
            "version",
        }
        
        class properties:
            
            
            class version(
                schemas.EnumBase,
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    enum_value_to_name = {
                        "EC_v1": "EC_V1",
                        "RSA_v1": "RSA_V1",
                    }
                
                @schemas.classproperty
                def EC_V1(cls):
                    return cls("EC_v1")
                
                @schemas.classproperty
                def RSA_V1(cls):
                    return cls("RSA_v1")
            data = schemas.StrSchema
            signature = schemas.StrSchema
        
            @staticmethod
            def header() -> typing.Type['ApplePayTokenHeader']:
                return ApplePayTokenHeader
            __annotations__ = {
                "version": version,
                "data": data,
                "signature": signature,
                "header": header,
            }
    
    data: MetaOapg.properties.data
    signature: MetaOapg.properties.signature
    header: 'ApplePayTokenHeader'
    version: MetaOapg.properties.version
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["version"]) -> MetaOapg.properties.version: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["data"]) -> MetaOapg.properties.data: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["signature"]) -> MetaOapg.properties.signature: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["header"]) -> 'ApplePayTokenHeader': ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["version", "data", "signature", "header", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["version"]) -> MetaOapg.properties.version: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["data"]) -> MetaOapg.properties.data: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["signature"]) -> MetaOapg.properties.signature: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["header"]) -> 'ApplePayTokenHeader': ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["version", "data", "signature", "header", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        data: typing.Union[MetaOapg.properties.data, str, ],
        signature: typing.Union[MetaOapg.properties.signature, str, ],
        header: 'ApplePayTokenHeader',
        version: typing.Union[MetaOapg.properties.version, str, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'ApplePayToken':
        return super().__new__(
            cls,
            *_args,
            data=data,
            signature=signature,
            header=header,
            version=version,
            _configuration=_configuration,
            **kwargs,
        )

from circle.model.apple_pay_token_header import ApplePayTokenHeader



# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from circle import schemas  # noqa: F401


class PresignMessage(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "from",
            "to",
            "nonce",
            "validBefore",
            "value",
            "validAfter",
        }
        
        class properties:
            _from = schemas.StrSchema
            to = schemas.StrSchema
            value = schemas.StrSchema
            validAfter = schemas.Int64Schema
            validBefore = schemas.Int64Schema
            nonce = schemas.StrSchema
            __annotations__ = {
                "from": _from,
                "to": to,
                "value": value,
                "validAfter": validAfter,
                "validBefore": validBefore,
                "nonce": nonce,
            }
    
    to: MetaOapg.properties.to
    nonce: MetaOapg.properties.nonce
    validBefore: MetaOapg.properties.validBefore
    value: MetaOapg.properties.value
    validAfter: MetaOapg.properties.validAfter
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["from"]) -> MetaOapg.properties._from: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["to"]) -> MetaOapg.properties.to: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["value"]) -> MetaOapg.properties.value: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["validAfter"]) -> MetaOapg.properties.validAfter: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["validBefore"]) -> MetaOapg.properties.validBefore: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["nonce"]) -> MetaOapg.properties.nonce: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["from", "to", "value", "validAfter", "validBefore", "nonce", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["from"]) -> MetaOapg.properties._from: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["to"]) -> MetaOapg.properties.to: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["value"]) -> MetaOapg.properties.value: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["validAfter"]) -> MetaOapg.properties.validAfter: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["validBefore"]) -> MetaOapg.properties.validBefore: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["nonce"]) -> MetaOapg.properties.nonce: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["from", "to", "value", "validAfter", "validBefore", "nonce", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        to: typing.Union[MetaOapg.properties.to, str, ],
        nonce: typing.Union[MetaOapg.properties.nonce, str, ],
        validBefore: typing.Union[MetaOapg.properties.validBefore, decimal.Decimal, int, ],
        value: typing.Union[MetaOapg.properties.value, str, ],
        validAfter: typing.Union[MetaOapg.properties.validAfter, decimal.Decimal, int, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'PresignMessage':
        return super().__new__(
            cls,
            *_args,
            to=to,
            nonce=nonce,
            validBefore=validBefore,
            value=value,
            validAfter=validAfter,
            _configuration=_configuration,
            **kwargs,
        )



# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from circle import schemas  # noqa: F401


class CheckoutSessionStatus(
    schemas.EnumBase,
    schemas.StrSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Status of the checkout session. Active: the checkout session is still in-progress. Completed: the payments of a checkout session is successful and the checkout session is completed. Expired: indicates that it expired and is no longer accepting any new payments.
    """
    
    @schemas.classproperty
    def ACTIVE(cls):
        return cls("active")
    
    @schemas.classproperty
    def COMPLETED(cls):
        return cls("completed")
    
    @schemas.classproperty
    def EXPIRED(cls):
        return cls("expired")



# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from circle import schemas  # noqa: F401


class Wire(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "trackingRef",
            "updateDate",
            "billingDetails",
            "fingerprint",
            "description",
            "id",
            "createDate",
            "status",
        }
        
        class properties:
            id = schemas.UUIDSchema
        
            @staticmethod
            def status() -> typing.Type['ExternalFiatAccountStatus']:
                return ExternalFiatAccountStatus
            description = schemas.StrSchema
            trackingRef = schemas.StrSchema
            fingerprint = schemas.StrSchema
        
            @staticmethod
            def billingDetails() -> typing.Type['BillingDetails']:
                return BillingDetails
            createDate = schemas.StrSchema
            updateDate = schemas.StrSchema
        
            @staticmethod
            def bankAddress() -> typing.Type['BankAddress']:
                return BankAddress
            __annotations__ = {
                "id": id,
                "status": status,
                "description": description,
                "trackingRef": trackingRef,
                "fingerprint": fingerprint,
                "billingDetails": billingDetails,
                "createDate": createDate,
                "updateDate": updateDate,
                "bankAddress": bankAddress,
            }
    
    trackingRef: MetaOapg.properties.trackingRef
    updateDate: MetaOapg.properties.updateDate
    billingDetails: 'BillingDetails'
    fingerprint: MetaOapg.properties.fingerprint
    description: MetaOapg.properties.description
    id: MetaOapg.properties.id
    createDate: MetaOapg.properties.createDate
    status: 'ExternalFiatAccountStatus'
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["status"]) -> 'ExternalFiatAccountStatus': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["description"]) -> MetaOapg.properties.description: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["trackingRef"]) -> MetaOapg.properties.trackingRef: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["fingerprint"]) -> MetaOapg.properties.fingerprint: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["billingDetails"]) -> 'BillingDetails': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["createDate"]) -> MetaOapg.properties.createDate: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["updateDate"]) -> MetaOapg.properties.updateDate: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["bankAddress"]) -> 'BankAddress': ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["id", "status", "description", "trackingRef", "fingerprint", "billingDetails", "createDate", "updateDate", "bankAddress", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["status"]) -> 'ExternalFiatAccountStatus': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["description"]) -> MetaOapg.properties.description: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["trackingRef"]) -> MetaOapg.properties.trackingRef: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["fingerprint"]) -> MetaOapg.properties.fingerprint: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["billingDetails"]) -> 'BillingDetails': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["createDate"]) -> MetaOapg.properties.createDate: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["updateDate"]) -> MetaOapg.properties.updateDate: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["bankAddress"]) -> typing.Union['BankAddress', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["id", "status", "description", "trackingRef", "fingerprint", "billingDetails", "createDate", "updateDate", "bankAddress", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        trackingRef: typing.Union[MetaOapg.properties.trackingRef, str, ],
        updateDate: typing.Union[MetaOapg.properties.updateDate, str, ],
        billingDetails: 'BillingDetails',
        fingerprint: typing.Union[MetaOapg.properties.fingerprint, str, ],
        description: typing.Union[MetaOapg.properties.description, str, ],
        id: typing.Union[MetaOapg.properties.id, str, uuid.UUID, ],
        createDate: typing.Union[MetaOapg.properties.createDate, str, ],
        status: 'ExternalFiatAccountStatus',
        bankAddress: typing.Union['BankAddress', schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'Wire':
        return super().__new__(
            cls,
            *_args,
            trackingRef=trackingRef,
            updateDate=updateDate,
            billingDetails=billingDetails,
            fingerprint=fingerprint,
            description=description,
            id=id,
            createDate=createDate,
            status=status,
            bankAddress=bankAddress,
            _configuration=_configuration,
            **kwargs,
        )

from circle.model.bank_address import BankAddress
from circle.model.billing_details import BillingDetails
from circle.model.external_fiat_account_status import ExternalFiatAccountStatus



# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from circle import schemas  # noqa: F401


class BusinessPayoutCreationRequest(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "amount",
            "idempotencyKey",
            "destination",
        }
        
        class properties:
            idempotencyKey = schemas.UUIDSchema
        
            @staticmethod
            def destination() -> typing.Type['BusinessDestinationRequest']:
                return BusinessDestinationRequest
        
            @staticmethod
            def amount() -> typing.Type['FiatMoney']:
                return FiatMoney
            __annotations__ = {
                "idempotencyKey": idempotencyKey,
                "destination": destination,
                "amount": amount,
            }
    
    amount: 'FiatMoney'
    idempotencyKey: MetaOapg.properties.idempotencyKey
    destination: 'BusinessDestinationRequest'
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["idempotencyKey"]) -> MetaOapg.properties.idempotencyKey: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["destination"]) -> 'BusinessDestinationRequest': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["amount"]) -> 'FiatMoney': ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["idempotencyKey", "destination", "amount", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["idempotencyKey"]) -> MetaOapg.properties.idempotencyKey: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["destination"]) -> 'BusinessDestinationRequest': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["amount"]) -> 'FiatMoney': ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["idempotencyKey", "destination", "amount", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        amount: 'FiatMoney',
        idempotencyKey: typing.Union[MetaOapg.properties.idempotencyKey, str, uuid.UUID, ],
        destination: 'BusinessDestinationRequest',
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'BusinessPayoutCreationRequest':
        return super().__new__(
            cls,
            *_args,
            amount=amount,
            idempotencyKey=idempotencyKey,
            destination=destination,
            _configuration=_configuration,
            **kwargs,
        )

from circle.model.business_destination_request import BusinessDestinationRequest
from circle.model.fiat_money import FiatMoney



# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from circle import schemas  # noqa: F401


class CvvResults(
    schemas.EnumBase,
    schemas.StrSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Enumerated status of the check. `not_requested` indicates check was not made. `pass` indicates value is correct. `fail` indicates value is incorrect. `unavailable` indicates card issuer did not do the provided check. `pending` indicates check is pending/processing.
    """
    
    @schemas.classproperty
    def NOT_REQUESTED(cls):
        return cls("not_requested")
    
    @schemas.classproperty
    def PASS(cls):
        return cls("pass")
    
    @schemas.classproperty
    def FAIL(cls):
        return cls("fail")
    
    @schemas.classproperty
    def UNAVAILABLE(cls):
        return cls("unavailable")
    
    @schemas.classproperty
    def PENDING(cls):
        return cls("pending")



# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from circle import schemas  # noqa: F401


class Wallet(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        
        class properties:
            walletId = schemas.StrSchema
            entityId = schemas.StrSchema
            
            
            class type(
                schemas.EnumBase,
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    enum_value_to_name = {
                        "end_user_wallet": "END_USER_WALLET",
                    }
                
                @schemas.classproperty
                def END_USER_WALLET(cls):
                    return cls("end_user_wallet")
            
            
            class description(
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    max_length = 255
            
            
            class balances(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['Money']:
                        return Money
            
                def __new__(
                    cls,
                    _arg: typing.Union[typing.Tuple['Money'], typing.List['Money']],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'balances':
                    return super().__new__(
                        cls,
                        _arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> 'Money':
                    return super().__getitem__(i)
            __annotations__ = {
                "walletId": walletId,
                "entityId": entityId,
                "type": type,
                "description": description,
                "balances": balances,
            }
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["walletId"]) -> MetaOapg.properties.walletId: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["entityId"]) -> MetaOapg.properties.entityId: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["type"]) -> MetaOapg.properties.type: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["description"]) -> MetaOapg.properties.description: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["balances"]) -> MetaOapg.properties.balances: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["walletId", "entityId", "type", "description", "balances", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["walletId"]) -> typing.Union[MetaOapg.properties.walletId, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["entityId"]) -> typing.Union[MetaOapg.properties.entityId, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["type"]) -> typing.Union[MetaOapg.properties.type, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["description"]) -> typing.Union[MetaOapg.properties.description, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["balances"]) -> typing.Union[MetaOapg.properties.balances, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["walletId", "entityId", "type", "description", "balances", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        walletId: typing.Union[MetaOapg.properties.walletId, str, schemas.Unset] = schemas.unset,
        entityId: typing.Union[MetaOapg.properties.entityId, str, schemas.Unset] = schemas.unset,
        type: typing.Union[MetaOapg.properties.type, str, schemas.Unset] = schemas.unset,
        description: typing.Union[MetaOapg.properties.description, str, schemas.Unset] = schemas.unset,
        balances: typing.Union[MetaOapg.properties.balances, list, tuple, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'Wallet':
        return super().__new__(
            cls,
            *_args,
            walletId=walletId,
            entityId=entityId,
            type=type,
            description=description,
            balances=balances,
            _configuration=_configuration,
            **kwargs,
        )

from circle.model.money import Money
